@@ -1,7 +1,7 @@
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 from bluedot_rest_framework import import_string
 
-EventChat = import_string('EVENT.chat.models')
+EventChat = import_string('event.chat.models')
 
 
 class EventChatSerializer(CustomSerializer):
