@@ -1,17 +1,14 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 
-class AbstractEventDataDownload(models.Model):
+class AbstractEventDataDownload(AbstractRelationTime):
     event_id = models.IntegerField()
-    title = models.CharField(max_length=32,default='')
+    title = models.CharField(max_length=32, default='')
     start_time = models.DateTimeField()
     end_time = models.DateTimeField()
 
     data = models.JSONField()
 
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
-
     class Meta:
         abstract = True
 
