@@ -73,7 +73,7 @@ class LiveView:
             if ppt and ppt.size > 20480000:
                 return Response({'code': 1003, 'msg': 'over size limit'})
 
-            ppt_path = os.getcwd()+'tmp_ppt/' + ppt_name
+            ppt_path = os.getcwd()+'/tmp_ppt/' + ppt_name
             with open(ppt_path, 'wb') as f:
                 data = ppt.read()
                 f.write(data)
@@ -81,7 +81,8 @@ class LiveView:
             image_list = ppt2images(ppt_path, ppt_name, event_id)
             queryset = EventLivePPT.objects.filter(event_id=event_id).first()
             if queryset:
-                queryset.update(image_list=image_list)
+                queryset.image_list = image_list
+                queryset.save()
             else:
                 EventLivePPT.objects.create(
                     event_id=event_id, image_list=image_list)
