@@ -1,7 +1,7 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 
-class AbstractEventSpeaker(models.Model):
+class AbstractEventSpeaker(AbstractRelationTime):
     event_id = models.IntegerField()
     name = models.CharField(max_length=255)
     jobs = models.CharField(max_length=255)
@@ -10,9 +10,6 @@ class AbstractEventSpeaker(models.Model):
     is_sign_page = models.BooleanField(default=False)
     sort = models.IntegerField(default=1)
 
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
-
     class Meta:
         abstract = True
 
