@@ -4,13 +4,15 @@ from bluedot_rest_framework.question.abstract_models import AbstractQuestion, Ab
 
 class EventVote(AbstractQuestion):
     event_id = models.IntegerField()
-    state= models.IntegerField(default=0)
+    schedule_id = models.IntegerField()
+    state = models.IntegerField(default=0)
 
     class Meta:
         db_table = 'event_vote'
 
 
 class EventVoteUser(AbstractQuestionUser):
+    schedule_id = models.IntegerField(default=0)
 
     class Meta:
         db_table = 'event_vote_user'
