@@ -47,9 +47,8 @@ class CustomModelViewSet(ModelViewSet):
 
 
 def user_perform_create(token, serializer):
-    user_id, openid, unionid, wechat_id = jwt_get_userinfo_handler(token)
-    serializer.save(user_id=user_id, openid=openid,
-                    unionid=unionid, wechat_id=wechat_id)
+    wechat_id, unionid = jwt_get_userinfo_handler(token)
+    serializer.save(unionid=unionid, wechat_id=wechat_id)
 
 
 class TreeAPIView(ListAPIView):
