@@ -9,11 +9,11 @@ from rest_framework.response import Response
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat, jwt_get_wechatid_handler
 
-from . import MiniProgram, OfficialAccount, WXBizDataCrypt, official_account_oauth
+from . import App, WXBizDataCrypt, official_account_oauth
 from .handle import WeChatUserSet
 from .models import WeChatUser
 from .serializers import WeChatUserSerializer
-User = import_string('USER.models')
+User = import_string('user.models')
 
 
 class JSSdk(APIView):
@@ -21,15 +21,16 @@ class JSSdk(APIView):
 
     def get(self, request, *args, **kwargs):
         referer = request.META['HTTP_REFERER']
+        appid = request.query_params.get('appid', '')
 
-        ticket = OfficialAccount.jsapi.get_jsapi_ticket()
+        ticket = App(appid).jsapi.get_jsapi_ticket()
         nonceStr = ''.join(random.sample(
             string.ascii_letters + string.digits, 8))
         timestamp = str(int(time.time()))
-        signature = OfficialAccount.jsapi.get_jsapi_signature(
+        signature = App(appid).jsapi.get_jsapi_signature(
             nonceStr, ticket, timestamp, referer)
         return Response({
-            'appId': settings.BLUEDOT_REST_FRAMEWORK['WECHAT']['OFFIACCOUNT']['APPID'],
+            'appId': appid,
             'timestamp': timestamp,
             'nonceStr': nonceStr,
             'signature': signature,
@@ -58,7 +59,7 @@ class JSSdk(APIView):
 #     def post(self, request, *args, **kwargs):
 #         auth_data = request.data['data']
 #         auth_user = WXBizDataCrypt(
-#             settings.WECHAT['MINIPROGRAM']['APPID'], auth_data['session_key']
+#             settings.wechat['miniprogram']['APPID'], auth_data['session_key']
 #         ).decrypt(auth_data['encryptedData'], auth_data['iv'])
 #         user_data = {
 #             'unionid': auth_user['unionId'],
@@ -86,14 +87,15 @@ class OAuth(APIView):
     permission_classes = ()
 
     def get(self, request, *args, **kwargs):
+        appid = request.query_params.get('appid', None)
         code = request.query_params.get('code', None)
         referer_uri = request.META['HTTP_REFERER']
-        if code:
+        if code and appid:
             wechat_oauth = official_account_oauth(
                 referer_uri, 'snsapi_userinfo')
             wechat_oauth.fetch_access_token(code)
             user_info = wechat_oauth.get_user_info()
-            token = WeChatUserSet(user_info=user_info).get_token()
+            token = WeChatUserSet(appid=appid, user_info=user_info).get_token()
             return Response({'token': token})
         else:
             wechat_oauth = official_account_oauth(
